pub enum IriSError {
ConvertingPathToIri {
path: String,
error: String,
},
IriParseError {
str: String,
error: String,
},
IriParseErrorWithBase {
str: String,
base: String,
error: String,
},
IriResolveError {
error: String,
base: Box<IriS>,
other: String,
},
JoinError {
error: String,
current: Box<IriS>,
str: String,
},
ReqwestClientCreation {
error: String,
},
UrlParseError {
str: String,
error: String,
},
ReqwestError {
error: String,
},
ReqwestTextError {
error: String,
},
ConvertingFileUrlToPath {
url: String,
},
IOErrorFile {
path: String,
url: String,
error: String,
},
TurtleParseError {
str: String,
error: String,
},
}Expand description
Errors that can occur when working with IriS
Variants
ConvertingPathToIri
Error converting a std::path::Path into an IRI
IriParseError
Error parsing an String into an IRI
IriParseErrorWithBase
Error parsing an String into an IRI using a base IRI
IriResolveError
Error resolving an IRI against a base IRI
JoinError
Error joining an IRI with a String
ReqwestClientCreation
Error creating a reqwest HTTP client
UrlParseError
Error parsing an IRI as a url::Url
ReqwestError
Error performing an HTTP request with reqwest
ReqwestTextError
Error performing an HTTP request with reqwest and obtaining the response as text
ConvertingFileUrlToPath
Error converting a file scheme url::Url into a std::path::Path
IOErrorFile
Error reading from a file obtained from a url::Url
TurtleParseError