macro_rules! static_once {
($name:ident, $type:ty, $init:expr) => { ... };
}Expand description
This macro creates a static variable that is initialized once andm can be accessed globally.
macro_rules! static_once {
($name:ident, $type:ty, $init:expr) => { ... };
}This macro creates a static variable that is initialized once andm can be accessed globally.