pub struct IriS { /* private fields */ }Implementations
Sourceimpl IriS
impl IriS
Sourcepub fn from_str_base(str: &str, base: Option<&str>) -> Result<IriS, IriSError>
pub fn from_str_base(str: &str, base: Option<&str>) -> Result<IriS, IriSError>
Create an IriS from a string with an optional base IRI string
Sourcepub fn from_str_base_iri(
str: &str,
base_iri: Option<&IriS>,
) -> Result<IriS, IriSError>
pub fn from_str_base_iri( str: &str, base_iri: Option<&IriS>, ) -> Result<IriS, IriSError>
Create an IriS from a string with an optional base IRI
Sourcepub fn named_node(&self) -> &NamedNode
pub fn named_node(&self) -> &NamedNode
Sourcepub fn new_unchecked(str: &str) -> IriS
pub fn new_unchecked(str: &str) -> IriS
Create an IriS from a &str without checking for possible syntactic errors
pub fn new(str: &str) -> Result<IriS, IriSError>
Sourcepub fn extend(&self, str: &str) -> Result<Self, IriSError>
pub fn extend(&self, str: &str) -> Result<Self, IriSError>
Extends the current IRI with a new string
This function checks for possible errors returning a Result
Sourcepub fn extend_unchecked(&self, str: &str) -> Self
pub fn extend_unchecked(&self, str: &str) -> Self
Extend an IRI with a new string without checking for possible syntactic errors
Sourcepub fn resolve(&self, other: IriS) -> Result<Self, IriSError>
pub fn resolve(&self, other: IriS) -> Result<Self, IriSError>
Resolve the IRI other with this IRI
Sourcepub fn resolve_str(&self, other: &str) -> Result<Self, IriSError>
pub fn resolve_str(&self, other: &str) -> Result<Self, IriSError>
Resolve other with this IRI
Sourcepub fn resolve_iri(&self, other: &str) -> Result<Iri<String>, IriSError>
pub fn resolve_iri(&self, other: &str) -> Result<Iri<String>, IriSError>
Resolve other with this IRI
Sourcepub fn namednode_from_iri(iri: Iri<String>) -> Result<NamedNode, IriSError>
pub fn namednode_from_iri(iri: Iri<String>) -> Result<NamedNode, IriSError>
Create a NamedNode from an IRI
pub fn parse_turtle(str: &str) -> Result<Self, IriSError>
Sourcepub fn dereference(&self, base: Option<&IriS>) -> Result<String, IriSError>
pub fn dereference(&self, base: Option<&IriS>) -> Result<String, IriSError>
Dereference the IRI and get the content available from it.
It handles also IRIs with the file scheme as local file names. For example: file:///person.txt